@@ -3,7 +3,10 @@ These objects are only for developers to use. Other objects are exposed
 to users in pymtl/__init__.py
 """
 from .Component import Component
+from .ComponentLevel1 import update
+from .ComponentLevel2 import update_ff
 from .ComponentLevel3 import connect
+from .ComponentLevel4 import update_once
 from .ComponentLevel5 import method_port
 from .ComponentLevel6 import non_blocking
 from .ComponentLevel7 import blocking
@@ -28,4 +31,5 @@ from .Connectable import (
     Wire,
 )
 from .ConstraintTypes import RD, WR, M, U
+from .MetadataKey import MetadataKey
 from .Placeholder import Placeholder
