@@ -11,8 +11,8 @@ from pymtl3.dsl.errors import UpblkCyclicError
 
 from ..DynamicSchedulePass import DynamicSchedulePass
 from ..GenDAGPass import GenDAGPass
+from ..PrepareSimPass import PrepareSimPass
 from ..SimpleSchedulePass import SimpleSchedulePass
-from ..SimpleTickPass import SimpleTickPass
 
 
 def _test_model( cls ):
@@ -20,14 +20,14 @@ def _test_model( cls ):
   A.elaborate()
   A.apply( GenDAGPass() )
   A.apply( DynamicSchedulePass() )
-  A.apply( SimpleTickPass() )
-  A.lock_in_simulation()
-  A.eval_combinational()
+  A.apply( PrepareSimPass() )
+
+  A.sim_reset()
+  A.sim_eval_combinational()
 
   T = 0
   while T < 5:
-    A.tick()
-    print(A.line_trace())
+    A.sim_tick()
     T += 1
   return A
 
@@ -36,52 +36,49 @@ def test_false_cyclic_dependency():
   class Top(Component):
 
     def construct( s ):
-      s.a = Wire(int)
-      s.b = Wire(int)
-      s.c = Wire(int)
-      s.d = Wire(int)
-      s.e = Wire(int)
-      s.f = Wire(int)
-      s.g = Wire(int)
-      s.h = Wire(int)
-      s.i = Wire(int)
-      s.j = Wire(int)
+      s.a = Wire(32)
+      s.b = Wire(32)
+      s.c = Wire(32)
+      s.d = Wire(32)
+      s.e = Wire(32)
+      s.f = Wire(32)
+      s.g = Wire(32)
+      s.h = Wire(32)
+      s.i = Wire(32)
+      s.j = Wire(32)
 
-      @s.update
+      @update
       def up1():
-        s.a = 10 + s.i
-        s.b = s.d + 1
+        s.a @= 10 + s.i
+        s.b @= s.d + 1
 
-      @s.update
+      @update
       def up2():
-        s.c = s.a + 1
-        s.e = s.d + 1
+        s.c @= s.a + 1
+        s.e @= s.d + 1
 
-      @s.update
+      @update
       def up3():
-        s.d = s.c + 1
+        s.d @= s.c + 1
         print("up3 prints out d =", s.d)
 
-      @s.update
+      @update
       def up4():
-        s.f = s.d + 1
+        s.f @= s.d + 1
 
-      @s.update
+      @update
       def up5():
-        s.g = s.c + 1
-        s.h = s.j + 1
+        s.g @= s.c + 1
+        s.h @= s.j + 1
         print("up5 prints out h =", s.h)
 
-      @s.update
+      @update
       def up6():
-        s.i = s.i + 1
+        s.i @= s.i + 1
 
-      @s.update
+      @update
       def up7():
-        s.j = s.g + 1
-
-    def done( s ):
-      return True
+        s.j @= s.g + 1
 
     def line_trace( s ):
       return "a {} | b {} | c {} | d {} | e {} | f {} | g {} | h {} | i {} | j {}" \
@@ -94,48 +91,45 @@ def test_combinational_loop():
   class Top(Component):
 
     def construct( s ):
-      s.a = Wire(int)
-      s.b = Wire(int)
-      s.c = Wire(int)
-      s.d = Wire(int)
+      s.a = Wire(32)
+      s.b = Wire(32)
+      s.c = Wire(32)
+      s.d = Wire(32)
 
-      @s.update
+      @update
       def up1():
-        s.b = s.d + 1
+        s.b @= s.d + 1
 
-      @s.update
+      @update
       def up2():
-        s.c = s.b + 1
+        s.c @= s.b + 1
 
-      @s.update
+      @update
       def up3():
-        s.d = s.c + 1
+        s.d @= s.c + 1
         print("up3 prints out d =", s.d)
 
-    def done( s ):
-      return True
-
     def line_trace( s ):
       return "a {} | b {} | c {} | d {}" \
               .format( s.a, s.b, s.c, s.d )
 
   try:
     _test_model( Top )
-  except Exception as e:
+  except UpblkCyclicError as e:
     print("{} is thrown\n{}".format( e.__class__.__name__, e ))
     return
-  raise Exception("Should've thrown Exception.")
+  raise Exception("Should've thrown UpblkCyclicError.")
 
 def test_very_deep_dag():
 
   class Inner(Component):
     def construct( s ):
-      s.in_ = InPort(int)
-      s.out = OutPort(int)
+      s.in_ = InPort(32)
+      s.out = OutPort(32)
 
-      @s.update
+      @update
       def up():
-        s.out = s.in_ + 1
+        s.out @= s.in_ + 1
 
     def done( s ):
       return True
@@ -149,8 +143,6 @@ def test_very_deep_dag():
       for i in range(N-1):
         s.inners[i].out //= s.inners[i+1].in_
 
-    def done( s ):
-      return True
     def line_trace( s ):
       return ""
 
@@ -164,11 +156,11 @@ def test_sequential_break_loop():
       s.b = Wire( Bits32 )
       s.c = Wire( Bits32 )
 
-      @s.update
+      @update
       def up1():
-        s.b = s.c + 1
+        s.b @= s.c + 1
 
-      @s.update_ff
+      @update_ff
       def up2():
         if s.reset:
           s.c <<= 0
@@ -189,21 +181,19 @@ def test_connect_slice_int():
 
   class Top( Component ):
     def construct( s ):
-      from pymtl3.datatypes import Bits8, Bits32
       s.y = OutPort( Bits8 )
       s.x = Wire( Bits32 )
 
       s.y //= s.x[0:8]
-      @s.update
+      @update
       def sx():
-        s.x = 10 # Except
+        s.x @= 10 # no Except
 
-  try:
-    _test_model( Top )
-  except TypeError as e:
-    assert str(e).startswith( "'int' object is not subscriptable" )
-    return
-  raise Exception("Should've thrown TypeError: 'int' object is not subscriptable")
+    def line_trace( s ):
+      return f"{s.x}"
+
+  # with @=, we don't have the subscript exception anymore
+  _test_model( Top )
 
 def test_const_connect_nested_struct_signal_to_struct():
 
@@ -226,9 +216,9 @@ def test_const_connect_nested_struct_signal_to_struct():
   x.elaborate()
   x.apply( GenDAGPass() )
   x.apply( DynamicSchedulePass() )
-  x.apply( SimpleTickPass() )
-  x.lock_in_simulation()
-  x.tick()
+  x.apply( PrepareSimPass(print_line_trace=False) )
+  x.sim_reset()
+  x.sim_tick()
   assert x.out == SomeMsg2(SomeMsg1(1,2),3)
 
 def test_const_connect_cannot_handle_same_name_nested_struct():
@@ -250,10 +240,14 @@ def test_const_connect_cannot_handle_same_name_nested_struct():
     a: A.SomeMsg1
     b: B.SomeMsg1
 
+  @bitstruct
+  class SomeMsg3:
+    a: SomeMsg2
+
   class Top( Component ):
     def construct( s ):
-      s.out = OutPort(SomeMsg2)
-      connect( s.out, SomeMsg2(A.SomeMsg1(1,2),B.SomeMsg1(3,4)) )
+      s.out = OutPort(SomeMsg3)
+      connect( s.out.a, SomeMsg2(A.SomeMsg1(1,2),B.SomeMsg1(3,4)) )
 
   x = Top()
   x.elaborate()
@@ -261,6 +255,63 @@ def test_const_connect_cannot_handle_same_name_nested_struct():
     x.apply( GenDAGPass() )
   except AssertionError as e:
     print(e)
-    assert str(e) == "Cannot handle two subfields with the same struct name but different structs"
+    assert str(e).startswith("Cannot handle two subfields with the same struct name but different structs")
     return
   raise Exception("Should've thrown AssertionError")
+
+def test_equal_top_level():
+  class A(Component):
+    def construct( s ):
+      @update
+      def up():
+        print(1)
+
+  a = A()
+  a.apply( GenDAGPass() )
+  a.apply( DynamicSchedulePass() )
+  a.apply( PrepareSimPass() )
+  a.sim_reset()
+
+  try:
+    a.reset = 0
+    a.sim_tick()
+  except AssertionError as e:
+    print(e)
+    assert str(e).startswith("Please use @= to assign top level InPort")
+    return
+  raise Exception("Should've thrown AssertionError")
+
+def test_update_once():
+
+  class A(Component):
+    @method_port
+    def recv( s, v ):
+      s.v = v
+
+    def construct( s ):
+      s.send = CallerPort()
+
+      s.v = None
+      @update_once
+      def up():
+        if s.v is not None:
+          s.send( s.v )
+
+      s.add_constraints( M(s.recv) < U(up) )
+
+  class Top(Component):
+    def construct( s ):
+      s.a = A()
+      s.b = A()
+      s.a.send //= s.b.recv
+      s.b.send //= s.a.recv
+
+  t = Top()
+  t.elaborate()
+  t.apply( GenDAGPass() )
+  try:
+    t.apply( DynamicSchedulePass() )
+  except UpblkCyclicError as e:
+    print(e)
+    return
+  raise Exception("Should've thrown UpblkCyclicError")
