@@ -28,7 +28,10 @@ class LineTraceParamPass( BasePass ):
               assert len( args ) == 0
               more_args = self._dsl.param_tree.leaf['line_trace'].items()
               kwargs.update({ x:y for x, y in more_args })
-        return self._ml_trace.line_trace( *args, **kwargs )
+        try:
+          return self._ml_trace.line_trace( *args, **kwargs )
+        except TypeError:
+          return self._ml_trace.line_trace()
 
       obj.line_trace = lambda *args, **kwargs : wrapped_line_trace( obj, *args, **kwargs )
 
